From 8bd9a02b1f45375b7545954880ea3b8ff8ac9c50 Mon Sep 17 00:00:00 2001
From: Michele Baldessari <michele@acksyn.org>
Date: Wed, 7 Feb 2024 12:28:01 +0100
Subject: [PATCH 2/2] Add DOCKER_RUN_OPTIONAL_ARGS variable when calling docker
 run

This allows us to add some needed optional arguments. Comes in handy
when using rootless podman:

    make DOCKER_RUN_OPTIONAL_ARGS="--userns=keep-id --security-opt label=disable" all
---
 Makefile | 6 +++++-
 1 file changed, 5 insertions(+), 1 deletion(-)

diff --git a/Makefile b/Makefile
index a4d6bd526..24cd519c3 100644
--- a/Makefile
+++ b/Makefile
@@ -72,11 +72,14 @@ CONTAINER_GID=$(shell id -g)
 
 # Set SUDO to sudo to run privileged commands with sudo
 SUDO?=
+# Optional additional run arguments
+DOCKER_RUN_OPTIONAL_ARGS?=
 
 # Runs any command in the argocd-test-utils container in server mode
 # Server mode container will start with uid 0 and drop privileges during runtime
 define run-in-test-server
 	$(SUDO) docker run --rm -it \
+		$(DOCKER_RUN_OPTIONAL_ARGS) \
 		--name argocd-test-server \
 		-u $(CONTAINER_UID):$(CONTAINER_GID) \
 		-e USER_ID=$(CONTAINER_UID) \
@@ -108,7 +111,8 @@ endef
 # Runs any command in the argocd-test-utils container in client mode
 define run-in-test-client
 	$(SUDO) docker run --rm -it \
-	  --name argocd-test-client \
+		$(DOCKER_RUN_OPTIONAL_ARGS) \
+		--name argocd-test-client \
 		-u $(CONTAINER_UID):$(CONTAINER_GID) \
 		-e HOME=/home/user \
 		-e GOPATH=/go \
-- 
2.43.2

